@@ -46,7 +46,7 @@ test_ecdsa (const struct ecc_curve *ecc,
   mpz_combit (signature.r, ecc->p.bit_size / 3);
   if (ecdsa_verify (&pub, h->length, h->data, &signature))
     {
-      fprintf (stderr, "ecdsa_verify unexpectedly succeeded with invalid signature.\n");
+      fprintf (stderr, "ecdsa_verify unexpectedly succeeded with invalid signature (r modified).\n");
       goto fail;
     }
   mpz_combit (signature.r, ecc->p.bit_size / 3);
@@ -54,7 +54,7 @@ test_ecdsa (const struct ecc_curve *ecc,
   mpz_combit (signature.s, 4*ecc->p.bit_size / 5);
   if (ecdsa_verify (&pub, h->length, h->data, &signature))
     {
-      fprintf (stderr, "ecdsa_verify unexpectedly succeeded with invalid signature.\n");
+      fprintf (stderr, "ecdsa_verify unexpectedly succeeded with invalid signature (s modified).\n");
       goto fail;
     }
   mpz_combit (signature.s, 4*ecc->p.bit_size / 5);
@@ -62,7 +62,7 @@ test_ecdsa (const struct ecc_curve *ecc,
   h->data[2*h->length / 3] ^= 0x40;
   if (ecdsa_verify (&pub, h->length, h->data, &signature))
     {
-      fprintf (stderr, "ecdsa_verify unexpectedly succeeded with invalid signature.\n");
+      fprintf (stderr, "ecdsa_verify unexpectedly succeeded with invalid signature (h modified).\n");
       goto fail;
     }
   h->data[2*h->length / 3] ^= 0x40;
@@ -81,6 +81,14 @@ test_ecdsa (const struct ecc_curve *ecc,
 void
 test_main (void)
 {
+  /* Test case provided by Guido Vranken, from oss-fuzz */
+  test_ecdsa (&_nettle_secp_192r1,
+	      "14683086 f1734c6d e68743a6 48181b54 a74d4c5b 383eb6a8", /* x */
+	      "  1e2584 2ab8b2b0 4017f655 1b5e4058 a2aa0612 2dae9344", /* y */
+	      SHEX("00"), /* h == 0 corner case*/
+	      "952800792ed19341fdeeec047f2514f3b0f150d6066151fb", /* r */
+	      "ec5971222014878b50d7a19d8954bc871e7e65b00b860ffb"); /* s */
+
   /* From RFC 4754 */
   test_ecdsa (&_nettle_secp_256r1,
 	      "2442A5CC 0ECD015F A3CA31DC 8E2BBC70"
@@ -145,17 +153,4 @@ test_main (void)
 	      "97536710 1F67D1CF 9BCCBF2F 3D239534" 
 	      "FA509E70 AAC851AE 01AAC68D 62F86647"
 	      "2660"); /* s */
-
-  test_ecdsa (&_nettle_curve25519,
-	      /* Public key corresponding to the key in ecdsa-sign-test */
-	      "59f8f317fd5f4e82 c02f8d4dec665fe1"
-	      "230f83b8572638e1 b2ac34a30028e24d", /* x */
-	      "1902a72dc1a6525a 811b9c1845978d56"
-	      "fd97dce5e278ebdd ec695349d7e41498", /* y */
-	      SHEX("e99df2a098c3c590 ea1e1db6d9547339"
-		   "ae760d5331496119 5d967fd881e3b0f5"), /* h */
-	      " 515c3a485f57432 0daf3353a0d08110"
-	      "64157c556296de09 4132f74865961b37", /* r */
-	      "  78f23367291b01 3fc430fb09322d95"
-	      "4384723649868d8e 88effc7ac8b141d7"); /* s */
 }
